""" Provides a GUI that allows the user to create a new basket. """
try:
    import Tkinter as tk
except ImportError:
    import tkinter as tk
from .messagebox_wrapper import tkMessageBoxWrapper as tkMessageBox


class CreateNewHotspotBasketGUI(tk.Frame):
    """Provides a GUI that allows the user to create a new basket."""

    def __init__(self, parent, root, *args, **kwargs):
        tk.Frame.__init__(self, parent, *args, **kwargs)
        self.root = root
        self.fill_frame()

    def fill_frame(self):
        """Fills the GUI frame with the appropriate elements."""

        tk.Label(
            self, text="With this menu you can create a new basket.", wraplength=400
        ).pack(side="top", anchor="nw", fill=tk.X, pady=20)

        tk.Label(self, text="Basket name").pack(side="top", anchor="nw", fill=tk.X)
        basket_name = tk.Entry(self)
        basket_name.pack(side="top", anchor="nw", fill=tk.X, pady=10)
        basket_name.delete(0, tk.END)
        self.basket_name_entry = basket_name

        tk.Button(self, text="Create Basket", command=self.create_basket).pack(
            side="top", anchor="center", pady=10
        )

    def create_basket(self):
        """Creates a basket according using the data the user provided."""
        name = self.basket_name_entry.get()
        if len(name) < 4:
            tkMessageBox.showerror(
                "Basket name too short.",
                "The basket name must be at least 4 characters long.",
            )
            return

        basket = self.root.viewer_instance.create_new_basket(name)

        tkMessageBox.showinfo(
            "Basket created succesfully.",
            "Basket created succesfully with id #%s." % basket.id,
        )


frame = CreateNewHotspotBasketGUI  # pylint: disable=C0103
