""" Provides a GUI that allows the user to load a basket. """
# pylint: disable=C0103,R0901,R0902,W0403,W0212,W0201
try:
    import Tkinter as tk
except ImportError:
    import tkinter as tk
from .load_hotspot_basket_gui import LoadHotspotBasketGUI
from .messagebox_wrapper import tkMessageBoxWrapper as tkMessageBox


class DeleteFromBasketGUI(LoadHotspotBasketGUI):
    """Provides a GUI that allows the user to load a basket."""

    def fill_frame(self):
        """Fills the GUI frame with the appropriate elements."""

        # List type indicator
        header_frame = tk.Frame(self)

        tk.Label(header_frame, text="Baskets").pack(side="left", anchor="nw")
        tk.Label(header_frame, text="Items").pack(side="right", anchor="ne")

        header_frame.pack(side="top", anchor="nw", fill=tk.X, pady=3)

        two_lists_frame = tk.Frame(self)
        LISTBOX_HEIGHT = 19
        LISTBOX_WIDTH = 36

        # Basket List box with scrollbar
        basket_list_frame = tk.Frame(two_lists_frame)
        basket_list_scrollbar = tk.Scrollbar(basket_list_frame, orient=tk.VERTICAL)
        basket_listbox = tk.Listbox(
            basket_list_frame,
            yscrollcommand=basket_list_scrollbar.set,
            height=LISTBOX_HEIGHT,
            width=LISTBOX_WIDTH,
            selectmode=tk.BROWSE,
        )
        basket_listbox.bind("<<ListboxSelect>>", self.show_basket_contents)
        self.basket_listbox = basket_listbox

        self.basket_list = ["No baskets available."]  # Placeholder message

        basket_list_scrollbar.config(command=basket_listbox.yview)
        basket_list_scrollbar.pack(side=tk.RIGHT, fill=tk.Y)
        basket_listbox.pack(side="top", anchor="nw", fill=tk.X, expand=True)

        basket_list_frame.pack(side="left", anchor="nw", fill=tk.X)

        # Item List box with scrollbar
        item_list_frame = tk.Frame(two_lists_frame)
        item_list_scrollbar = tk.Scrollbar(item_list_frame, orient=tk.VERTICAL)

        item_listbox = tk.Listbox(
            item_list_frame,
            yscrollcommand=item_list_scrollbar.set,
            height=LISTBOX_HEIGHT,
            width=LISTBOX_WIDTH,
            selectmode=tk.EXTENDED,
        )

        self.item_listbox = item_listbox

        self.items_list = ["No items available."]  # Placeholder message

        item_list_scrollbar.config(command=basket_listbox.yview)
        item_list_scrollbar.pack(side=tk.RIGHT, fill=tk.Y)
        item_listbox.pack(side="top", anchor="nw", fill=tk.X, expand=True)

        item_list_frame.pack(side="right", anchor="ne", fill=tk.X)

        two_lists_frame.pack(side="top", anchor="nw", fill=tk.X)

        # Button bar
        button_bar_frame = tk.Frame(self)

        delete_from_basket_button = tk.Button(
            button_bar_frame,
            text="Remove selected items from basket",
            command=self.delete_from_basket,
        )
        delete_from_basket_button.pack(side="right", anchor="nw", padx=10, pady=10)

        button_bar_frame.pack(side="top", anchor="nw", fill=tk.X)

    def delete_from_basket(self, skip_ask=False):
        """Deletes a basket. asks the user for permission first."""
        selection = self.item_listbox.curselection()
        if len(selection) == 0:
            return

        if not skip_ask:
            user_response = tkMessageBox.askyesno(
                "Remove items from basjet",
                "Are you sure you want to remove the items from this basket?",
            )
            if not user_response:
                return False

        positions = [self.items_list[sel].split(":")[0] for sel in selection]
        try:
            self.root.viewer_instance.delete_items_from_basket(
                positions, self.selected_basket_id
            )
        except AssertionError as err:
            denied_item = str(err).split(" ")[1]
            if skip_ask:
                raise err
            else:
                tkMessageBox.showwarning(
                    "Could not remove certain items.",
                    "The following item could not be removed: "
                    + denied_item
                    + "\nDo you have permission to this item?",
                )

        # Reload the items list
        self.items_list = self.load_basket(self.selected_basket_id)
        self.fill_item_listbox()

        return True


frame = DeleteFromBasketGUI
