""" A wrapper for tkMessageBoxes """
# pylint: disable=R0903,C0103

import traceback

try:
    import tkMessageBox
except (ImportError):
    import tkinter.messagebox as tkMessageBox


class TkMessageBoxWrapperClass(object):
    """A wrapper for tkMessageBoxes"""

    def __getattr__(self, item):
        """Returns a normal tkMessageBox function under normal operation but raises an error when
        a message box appears during training to prevent the testing process from stalling and
        timing out."""
        for line in traceback.extract_stack():
            if "pymol/test/test_" in line[0]:
                return (
                    self.raise_error
                )  # Raise an error instead of showing the message box.

        return getattr(tkMessageBox, item)

    @staticmethod
    def raise_error(*args, **kwargs):
        """Raise a RuntimeError containing the details that would've been sent in the
        message box during normal operation."""
        raise RuntimeError(
            "Application attempted to show a message box with the following contents: \n"
            + "Arguments: "
            + str(args)
            + "\n"
            + "Keyword arguments: "
            + str(kwargs)
        )


# Remember to import tkMessageBoxWrapper, as we need an instance of the class
tkMessageBoxWrapper = TkMessageBoxWrapperClass()
