""" Provides a GUI that allows the user to pick a family. """
# pylint: disable=C0103,R0901,W0403
from .viewer_variable_picker import ViewerVariablePickerGUI
from .messagebox_wrapper import tkMessageBoxWrapper as tkMessageBox


class PickFamilyGUI(ViewerVariablePickerGUI):
    """Provides a GUI that allows the user to pick a family."""

    def __init__(self, parent, root, show_messages=True, *args, **kwargs):
        ViewerVariablePickerGUI.__init__(self, parent, root, *args, **kwargs)
        self.default_search_message = "Search families"
        self.label_message = "Select an alignment to work with."
        self.show_messages = show_messages

    def load_values_list(self):
        """Load the list of systems/superfamilies the currently logged in user has access to."""
        try:
            families = self.root.viewer_instance.load_alignment_families(
                self.root.viewer_instance
            )
        except (AttributeError, RuntimeError):
            families = {
                "You must select a 3DM system before selecting an alignment.": ""
            }

        families = sorted(families.items(), key=lambda x: x[1])
        families = ["%s (%s)" % (name, _id) for name, _id in families]

        self.values_list = families

    def set_viewer_variable(self):
        """Sets the system variable on the viewer instance."""
        selected_value = self.get_selected_value()
        if not selected_value:
            if self.show_messages:
                tkMessageBox.showerror(
                    "You cannot select this alignment.",
                    "You must select a 3DM system before selecting an alignment,"
                    " or you didn't select an alignment from the list.",
                )
            return

        self.root.viewer_instance.storage.family = int(selected_value)
        if self.show_messages:
            tkMessageBox.showinfo(
                "Set new alignment value.",
                "Successfully selected a new alignment. (%s in system %s)"
                % (
                    self.root.viewer_instance.storage.family,
                    self.root.viewer_instance.storage.system,
                ),
            )
        return True


frame = PickFamilyGUI
