""" Provides a GUI that allows the user to pick a subset. """
# pylint: disable=C0103,R0901,W0403
from .viewer_variable_picker import ViewerVariablePickerGUI
from .messagebox_wrapper import tkMessageBoxWrapper as tkMessageBox


class PickSubsetGUI(ViewerVariablePickerGUI):
    """Provides a GUI that allows the user to pick a subset."""

    def __init__(self, parent, root, show_messages=True, *args, **kwargs):
        ViewerVariablePickerGUI.__init__(self, parent, root, *args, **kwargs)
        self.default_search_message = "Search subsets"
        self.label_message = "Select a subset to work with."
        self.show_messages = show_messages

    def load_values_list(self):
        """Load the list of subsets the currently logged in user has access to."""
        try:
            subsets = self.root.viewer_instance.load_alignment_subsets(
                self.root.viewer_instance
            )
        except (AttributeError, RuntimeError) as e:
            raise e
            subsets = {"You must select a superfamily before selecting a subset.": ""}

        subsets = sorted(subsets.items(), key=lambda x: x[1])
        subsets = ["%s (%s)" % (name, _id) for name, _id in subsets]
        self.values_list = subsets

    def set_viewer_variable(self):
        """Sets the system variable on the viewer instance."""
        selected_value = self.get_selected_value()
        if not selected_value:
            if self.show_messages:
                tkMessageBox.showerror(
                    "You cannot select this subset.",
                    "You must select a superfamily before selecting a subset,"
                    " or you didn't select a subset from the list.",
                )
            return
        self.root.viewer_instance.storage.subset = int(selected_value)
        if self.show_messages:
            tkMessageBox.showinfo(
                "Set new subset value.",
                "Successfully selected a new subset. (%s)" % selected_value,
            )
        return True


frame = PickSubsetGUI
