""" Provides a GUI that allows the user to pick a superfamily or system. """
# pylint: disable=C0103,R0901,W0403
from .viewer_variable_picker import ViewerVariablePickerGUI
from .messagebox_wrapper import tkMessageBoxWrapper as tkMessageBox


class PickSystemGUI(ViewerVariablePickerGUI):
    """Provides a GUI that allows the user to pick a superfamily."""

    def __init__(self, parent, root, show_messages=True, *args, **kwargs):
        ViewerVariablePickerGUI.__init__(self, parent, root, *args, **kwargs)
        self.show_messages = show_messages

    def load_values_list(self):
        """Load the list of systems/superfamilies the currently logged in user has access to."""
        access_api = self.root.viewer_instance._get_api(
            "access"
        )  # pylint: disable=W0212
        self.values_list = list(
            self.root.viewer_instance.load_accessible_systems(access_api).keys()
        )

    def set_viewer_variable(self):
        """Sets the system variable on the viewer instance."""
        selected_value = self.get_selected_value()
        if selected_value is None:
            if self.show_messages:
                tkMessageBox.showinfo(
                    "No value selected.",
                    "You must select a value from the list to use it as 3DM system.",
                )
            return
        self.root.viewer_instance.storage.system = selected_value.replace("-", "_")
        if self.show_messages:
            tkMessageBox.showinfo(
                "Set new 3DM system value.",
                "Set '%s' as the new 3DM system." % selected_value,
            )
        return True


frame = PickSystemGUI
