""" A frame that shows information about the plugin. """
# pylint: disable=C0103,W0406

import os
import pprint

try:
    import Tkinter as tk
except ImportError:
    import tkinter as tk

from datetime import date
from ....shared.viewer.Updates import Updates
from .messagebox_wrapper import tkMessageBoxWrapper as tkMessageBox


class ShowAboutGUI(tk.Frame):
    """A frame that shows information about the plugin."""

    def __init__(self, parent, root, *args, **kwargs):
        tk.Frame.__init__(self, parent, *args, **kwargs)
        self.root = root
        self.fill_frame()

    def get_version_text(self):
        """Returns an appropriate text for indicating the state of the plugin with regard to the
        currently released version of the plugin."""
        latest_released_version = Updates.get_latest_stable_version("pymol")
        if self.root.viewer_instance.VERSION.split(".") < latest_released_version.split(
            "."
        ):
            version_text = "A new version is available: %s" % latest_released_version
        elif self.root.viewer_instance.VERSION.split(
            "."
        ) > latest_released_version.split("."):
            version_text = "You are using a pre-release version."
        else:
            version_text = "You are up to date."

        return version_text

    def show_storage(self):
        """Shows a nicely formatted version of the current storage array."""
        storage_str = pprint.pformat(self.root.viewer_instance.storage.__dict__)
        tkMessageBox.showinfo("Storage information", storage_str)

    def fill_frame(self):
        """Fills the GUI frame with the appropriate elements."""
        current_year = date.today().year

        texts = [
            "About Bio-Prodict 3DM",
            "3DM YASARA Plugin v%s" % self.root.viewer_instance.VERSION,
            "%s, Bio-Prodict B.V." % current_year,
            "Support: support@bio-prodict.nl",
            "Website: www.bio-prodict.nl",
            self.get_version_text(),
        ]
        for text in texts:
            tk.Label(self, text=text).pack(side="top", anchor="nw", fill=tk.X)

        logo_path = os.path.abspath(
            os.path.join(
                os.path.dirname(__file__), "../assets/images/bioprodict_logo.gif"
            )
        )

        self.logo = tk.PhotoImage(master=self, file=logo_path)

        self.logo_label = tk.Label(self, image=self.logo, text="text")
        self.logo_label.pack(expand=True, fill=tk.BOTH)

        self.storage_logo = tk.Button(
            self, text="Show debug storage information", command=self.show_storage
        ).pack(expand=True, fill=tk.BOTH)


frame = ShowAboutGUI
