""" A frame that allows the user to log in to search for literature hotspots. """
# pylint: disable=C0103,W0403

try:
    import Tkinter as tk
except ImportError:
    import tkinter as tk
from .tkinter_utilities import is_int


class ShowLiteratureHotspotsGUI(tk.Frame):
    """A frame that allows the user to log in to 3DM."""

    def __init__(self, parent, root, *args, **kwargs):
        tk.Frame.__init__(self, parent, *args, **kwargs)
        self.root = root
        self.fill_frame()

    def fill_frame(self):
        """Fills the GUI frame with the appropriate elements."""
        tk.Label(
            self,
            text="Please enter any combination of words to find hotspots in the structure for "
            "those keywords. You can find more details in the Scene Content Details window.",
            wraplength=600,
        ).pack(side="top", anchor="nw", fill=tk.X, pady=20)

        tk.Label(self, text="Keywords").pack(side="top", anchor="nw", fill=tk.X)
        keywords = tk.Entry(self)
        keywords.pack(side="top", anchor="nw", fill=tk.X, pady=10)
        self.keywords_entry = keywords

        tk.Label(
            self, text="Limit, the maximum amount of hotspots that should be shown."
        ).pack(side="top", anchor="center", fill=tk.X)
        is_int_cmd = (self.register(is_int), "%P")

        limit_variable = tk.IntVar(self)
        limit_variable.set(25)  # Default maxvalue value
        limit = tk.Entry(
            self,
            text=limit_variable,
            validate="key",
            width=5,
            validatecommand=is_int_cmd,
        )

        limit.pack(side="top", anchor="n", pady=10)
        self.limit_entry = limit

        tk.Label(
            self, text="Cutoff, the minimum amount of mentions a hotspot should have."
        ).pack(side="top", anchor="center", fill=tk.X)

        is_int_cmd = (self.register(is_int), "%P")
        cutoff_variable = tk.IntVar(self)
        cutoff_variable.set(2)  # Default maxvalue value
        cutoff = tk.Entry(
            self,
            text=cutoff_variable,
            validate="key",
            width=5,
            validatecommand=is_int_cmd,
        )

        cutoff.pack(side="top", anchor="n", pady=10)
        self.cutoff_entry = cutoff

        self.message_text = tk.StringVar()
        self.message_text.set("")
        self.message_label = tk.Label(self, textvariable=self.message_text)
        self.message_label.pack(side="top", anchor="nw", fill=tk.X)

        tk.Button(self, text="Search", command=self.show_literature_hotspots).pack(
            side="top", anchor="center", pady=10
        )

    def show_literature_hotspots(self):
        """Calls the show_literature_hotspots method in PyMolViewer with the submitted terms."""
        terms = self.keywords_entry.get().split(" ")
        cutoff = self.cutoff_entry.get()
        limit = self.limit_entry.get()
        self.message_text.set("Displaying results for '%s'." % terms)
        try:
            self.root.viewer_instance.show_literature_hotspots(
                terms, cutoff=int(cutoff), limit=int(limit)
            )
            self.root.switch_to_scene_details()
        except ValueError:
            self.message_text.set("No results for '%s'." % terms)


frame = ShowLiteratureHotspotsGUI
