""" Supplies a configuration singleton. """
# pylint: disable=R0903,W0403
import json
import os
from .Singleton import Singleton


class Config(Singleton):
    """A singleton that supplies configuration information from a JSON file. This class is a
    Singleton so that any changes to it will propagate to other places where the config is used,
    without reinstantiating. The configuration is explicitly meant to be global."""

    def __init__(self):
        """Initializes the instance, loading the configuration file and storing the properties
        inside as attributes. Uses either a default configuration file or any other JSON file
        given by the THREEDM_PLUGIN_CONFIG environment variable."""

        env_name = "THREEDM_PLUGIN_CONFIG"
        if os.getenv(env_name) is not None:
            config_path = os.getenv(env_name)
        else:
            config_path = os.path.join(os.path.dirname(__file__), "..", "config.json")

        self.path = os.path.abspath(config_path)

        with open(config_path) as configuration_file:
            config = json.load(configuration_file)
            for key, value in config.items():
                setattr(self, key, value)
