""" Provides a very basic Storage object with export methods. """
# pylint: disable=R0902
import json


class Storage(object):
    """Basic storage object."""

    def as_json(self):
        """Returns the current state of the Storage instance as a JSON string."""
        serializable = {}
        for key, value in self.__dict__.items():
            try:
                # Add the separators argument to reduce size (removes redundant spaces)
                json.dumps({key: value}, separators=(",", ":"))
                serializable[key] = value
            except TypeError:
                print("Skipped dumping key '%s' (instance of %s)" % (key, type(value)))

        return json.dumps(serializable)

    def load_from_json(self, data):
        """Loads a saved state from a JSON string."""
        for key, value in json.loads(data).items():
            setattr(self, key, value)
